@@ -17,6 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/*
+ * Modified by the GLib Team and others 1997-1999.  See the AUTHORS
+ * file for a list of people on the GLib Team.  See the ChangeLog
+ * files for a list of changes.  These files are distributed with
+ * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ */
+
 /* 
  * MT safe
  */
@@ -285,7 +292,11 @@ g_realloc (gpointer mem,
   
   
   if (size == 0)
-    return NULL;
+    {
+      g_free (mem);
+    
+      return NULL;
+    }
   
   
 #if defined(ENABLE_MEM_PROFILE) || defined(ENABLE_MEM_CHECK)
@@ -298,7 +309,7 @@ g_realloc (gpointer mem,
   
   
   if (!mem)
-    p = (gpointer) malloc (size);
+    p = (gpointer) realloc (NULL, size);
   else
     {
 #if defined(ENABLE_MEM_PROFILE) || defined(ENABLE_MEM_CHECK)
